import { values, map, zipObj, split, compose, head } from 'ramda';
import ALL_LOCALES from './locale-keys';

export const LOCALE_KEYS = ALL_LOCALES;

export const LOCALE = 'locale';

/**
 * [ 'en-us', 'de-de' ]
 */
export const LOCALES = values(LOCALE_KEYS);
export const DEFAULT_LOCALE = LOCALE_KEYS.EN_US;
/**
 * [ 'en', 'de' ]
 */
export const LANGS = map(compose(head, split('-')), LOCALES);
/**
 * {
 *    en-us: 'en',
 *    de-de: 'de',
 * }
 */
export const LANG_KEYS = zipObj(LOCALES, LANGS);
/**
 * {
 *    en: 'en-us',
 *    de: 'de-de',
 * }
 */
export const LANG_TO_LOCALE = zipObj(LANGS, LOCALES);
export const DEFAULT_LANG = LANG_KEYS[LOCALE_KEYS.EN_US];

export const LANG_NAMES = {
  [LOCALE_KEYS.AZ_AZ]: 'Azərbaycan dili', // Azerbaijani
  [LOCALE_KEYS.ID_ID]: 'Bahasa Indonesia', // Indonesian
  [LOCALE_KEYS.MS_MY]: 'Bahasa Melayu', // Malay
  [LOCALE_KEYS.DA_DK]: 'Dansk', // Danish
  [LOCALE_KEYS.DE_DE]: 'Deutsch', // German
  [LOCALE_KEYS.EN_US]: 'English', // English
  [LOCALE_KEYS.ES_ES]: 'Español', // Spanish
  [LOCALE_KEYS.EL_GR]: 'Ελληνικά', // Greek
  [LOCALE_KEYS.EN_PH]: 'Filipino', // Phillipino
  [LOCALE_KEYS.FR_FR]: 'Français', // French
  [LOCALE_KEYS.EN_IN]: 'Indian', // Indian
  [LOCALE_KEYS.IT_IT]: 'Italiano', // Italian
  [LOCALE_KEYS.NL_NL]: 'Nederlands', // Dutch
  [LOCALE_KEYS.PL_PL]: 'Polski', // Polish
  [LOCALE_KEYS.PT_PT]: 'Português', // Portuguese
  [LOCALE_KEYS.RO_RO]: 'Română', // Romanian
  [LOCALE_KEYS.FI_FI]: 'Suomi', // Finnish
  [LOCALE_KEYS.VI_VN]: 'Tiếng Việt', // Vietnamese
  [LOCALE_KEYS.TR_TR]: 'Türkçe', // Turkish
  [LOCALE_KEYS.BE_BY]: 'Беларуская', // Belarusian
  [LOCALE_KEYS.RU_RU]: 'Русский', // Russian
  [LOCALE_KEYS.UK_UA]: 'Українська', // Ukrainian
  [LOCALE_KEYS.ZH_CN]: '中文', // Chinese
  [LOCALE_KEYS.KO_KR]: '한국어', // Korean
  [LOCALE_KEYS.AR_EG]: 'العربية', // Arabic
  [LOCALE_KEYS.HI_IN]: 'हिन्दी', // Hindi
  [LOCALE_KEYS.FA_IR]: 'فارسی', // Persian
  [LOCALE_KEYS.HE_IL]: 'עברית', // Hebrew
};

export const AVAILABLE_LOCALES = [
  LOCALE_KEYS.EN_US,
  LOCALE_KEYS.RU_RU,
  LOCALE_KEYS.ZH_CN,
  LOCALE_KEYS.ES_ES,
  LOCALE_KEYS.KO_KR,
  LOCALE_KEYS.AR_EG,
  LOCALE_KEYS.EN_IN,
  LOCALE_KEYS.TR_TR,
];

export const LOCALES_DOMAIN_MAPPING = {
  [LOCALE_KEYS.EN_US]: 'com',
  [LOCALE_KEYS.RU_RU]: 'me',
  [LOCALE_KEYS.ZH_CN]: 'net',
  [LOCALE_KEYS.ES_ES]: 'es',
  [LOCALE_KEYS.KO_KR]: 'kr',
  [LOCALE_KEYS.EN_IN]: 'in',
  [LOCALE_KEYS.TR_TR]: 'tc',
};

export const CURRENCY_USD = 'USD';
export const CURRENCY_EUR = 'EUR';
export const ALL_CURRENCY = [CURRENCY_USD, CURRENCY_EUR];
export const DEFAULT_CURRENCY = CURRENCY_USD;

export const DEFAULT_RESET_STATE_TIMEOUT = 3000;

export const USERNAME_LENGTH_MAX = 16;
export const MEMO_LENGTH_MAX = 500;

export const MIN_FRACTION_DIGITS = 3;
export const MAX_FRACTION_DIGITS = 9;

// Errors, alerts
export const UNDEFINED_ERROR_ID = 'general.error.unknown';
export const SIGN_UP_ERROR_UNKNOWN = 'general.sign-up.error.unknown';

export const CHAR_CODES = {
  ENTER: 13,
  CONTROL: 31,
  DOT: 46,
  ZERO: 48,
  NINE: 57,
};
